IoSliceMut

Struct IoSliceMut 

pub struct IoSliceMut<'a>(/* private fields */);
A buffer type used for readv.

This is a wrapper around an std::io::IoSliceMut, but does not expose the inner bytes in a safe API, as they may point at uninitialized memory.

This is repr(transparent) of the std::io::IoSliceMut, so it is valid to transmute them. However, as the memory might be uninitialized, care must be taken to not read the internal bytes, only write to them.